PyramidIO
=========

.. currentmodule:: toasty.pyramid

.. autoclass:: PyramidIO
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PyramidIO.clean_lockfiles
      ~PyramidIO.get_default_format
      ~PyramidIO.get_default_vertical_parity_sign
      ~PyramidIO.get_path_scheme
      ~PyramidIO.open_metadata_for_read
      ~PyramidIO.open_metadata_for_write
      ~PyramidIO.read_image
      ~PyramidIO.tile_path
      ~PyramidIO.update_image
      ~PyramidIO.write_image

   .. rubric:: Methods Documentation

   .. automethod:: clean_lockfiles
   .. automethod:: get_default_format
   .. automethod:: get_default_vertical_parity_sign
   .. automethod:: get_path_scheme
   .. automethod:: open_metadata_for_read
   .. automethod:: open_metadata_for_write
   .. automethod:: read_image
   .. automethod:: tile_path
   .. automethod:: update_image
   .. automethod:: write_image
